@@ -94,7 +94,12 @@ class PytestMultihostOutput:
                 ip = provisioned_host.ip
                 dns_record = resolve_hostname(ip)
                 host["ip"] = ip
-                host["external_hostname"] = dns_record
+
+                # Using IP as backup for external host name as pytest-multihost is using
+                # external_hostname as the host to use in ssh command.
+                # If it is not available it uses hostname, but we assume here that
+                # hostname is internal and thus not resolvable. IP should be resolvable.
+                host["external_hostname"] = dns_record or ip
 
                 if host["group"] == "ad_root":
                     mhcfg["ad_top_domain"] = domain["name"]
@@ -117,10 +122,10 @@ class PytestMultihostOutput:
 
         # ssh_key_filename must be absolute as it can be used from a different
         # working directory, e.g. running tests from git repo
-        ssh_key_filename = self._config.get("ssh_key_filename")
+        ssh_key_filename = mhcfg.get("ssh_key_filename")
 
         # Update with SSH key path only if not already defined in mhcfg
-        if ssh_key_filename and not mhcfg.get("ssh_key_filename"):
+        if ssh_key_filename and not self._metadata.get("ssh_key_filename"):
             mhcfg["ssh_key_filename"] = os.path.abspath(ssh_key_filename)
 
         return mhcfg
